==> zhongyan-manage-service-api-yyjh-01-20220914.053753-4-sources.jar: cn/com/duiba/cloud/manage/service/api/model/constant/dept/export/ExportTemplatePathConstant.java <==
package cn.com.duiba.cloud.manage.service.api.model.constant.dept.export;

/**
 * @author linzhou
 * @ClassName ExportTemplatePathConstant.java
 * @createTime 2021年12月02日 14:00:00
 * @Description 导出导入模板常量类
 */
public class ExportTemplatePathConstant {
    public static final String EXPORT_STAFF_INVITE_TEMPLATE_PATH = "export/员工管理失败导出模版.xlsx";

    public static final String EXPORT_ROLE_STAFF_TEMPLATE_PATH = "export/角色员工失败导出模版.xlsx";

    public static final String EXPORT_DEPT_STAFF_TEMPLATE_PATH = "export/部门员工导出模板.xlsx";

    public static final String EXPORT_STATISTICS_PAGE_TEMPLATE_PATH = "export/页面数据明细导出模板.xlsx";

    public static final String EXPORT_STATISTICS_UNIT_TEMPLATE_PATH = "export/组件数据明细导出模板.xlsx";

    public static final String EXPORT_SUPPLIER_GOODS_TEMPLATE_PATH = "export/供应商商品导出模板.xlsx";

    public static final String EXPORT_TAG_USER_TEMPLATE_PATH = "export/标签值用户关联失败导出模版.xlsx";

    public static final String EXPORT_WECHAT_DATA_DETAIL_TEMPLATE_PATH = "export/微信二维码数据明细导出模板.xlsx";

    public static final String EXPORT_CHEAT_LIST_TEMPLATE_PATH = "export/黑灰名单导入失败导出模版.xlsx";

    public static final String EXPORT_ACTIVITY_DATA_TEMPLATE_PATH = "export/活动数据导入失败导出模版.xlsx";


    public static final String EXPORT_PEACE_REMAIN_TEMPLATE_PATH = "export/平和星余额报表模板.xlsx";

    public static final String EXPORT_ACTIVITY_JOIN_TEMPLATE_PATH = "export/心中的远方参与模板.xlsx";

    public static final String EXPORT_ACTIVITY_TASK_TEMPLATE_PATH = "export/心中的远方任务模板.xlsx";

    public static final String EXPORT_ACTIVITY_PRIZE_TEMPLATE_PATH = "export/心中的远方奖品模板.xlsx";
    public static final String EXPORT_USER_VIEW_TEMPLATE_PATH = "export/时段独立访客数报表模板.xlsx";

    public static final String EXPORT_USER_ADDRESS_TEMPLATE_PATH = "export/用户地区报表模版.xlsx";
}

==> zhongyan-manage-service-api-yyjh-02-20221010.025815-23-sources.jar: cn/com/duiba/cloud/manage/service/api/model/constant/dept/export/ExportTemplatePathConstant.java <==
package cn.com.duiba.cloud.manage.service.api.model.constant.dept.export;

/**
 * @author linzhou
 * @ClassName ExportTemplatePathConstant.java
 * @createTime 2021年12月02日 14:00:00
 * @Description 导出导入模板常量类
 */
public class ExportTemplatePathConstant {
    public static final String EXPORT_STAFF_INVITE_TEMPLATE_PATH = "export/员工管理失败导出模版.xlsx";

    public static final String EXPORT_ROLE_STAFF_TEMPLATE_PATH = "export/角色员工失败导出模版.xlsx";

    public static final String EXPORT_DEPT_STAFF_TEMPLATE_PATH = "export/部门员工导出模板.xlsx";

    public static final String EXPORT_STATISTICS_PAGE_TEMPLATE_PATH = "export/页面数据明细导出模板.xlsx";

    public static final String EXPORT_STATISTICS_UNIT_TEMPLATE_PATH = "export/组件数据明细导出模板.xlsx";

    public static final String EXPORT_SUPPLIER_GOODS_TEMPLATE_PATH = "export/供应商商品导出模板.xlsx";

    public static final String EXPORT_TAG_USER_TEMPLATE_PATH = "export/标签值用户关联失败导出模版.xlsx";

    public static final String EXPORT_WECHAT_DATA_DETAIL_TEMPLATE_PATH = "export/微信二维码数据明细导出模板.xlsx";

    public static final String EXPORT_CHEAT_LIST_TEMPLATE_PATH = "export/黑灰名单导入失败导出模版.xlsx";

    public static final String EXPORT_ACTIVITY_DATA_TEMPLATE_PATH = "export/活动数据导入失败导出模版.xlsx";


    public static final String EXPORT_PEACE_REMAIN_TEMPLATE_PATH = "export/平和星余额报表模板.xlsx";

    public static final String EXPORT_ACTIVITY_JOIN_TEMPLATE_PATH = "export/心中的远方参与模板.xlsx";

    public static final String EXPORT_ACTIVITY_TASK_TEMPLATE_PATH = "export/心中的远方任务模板.xlsx";

    public static final String EXPORT_ACTIVITY_PRIZE_TEMPLATE_PATH = "export/心中的远方奖品模板.xlsx";
    public static final String EXPORT_USER_VIEW_TEMPLATE_PATH = "export/时段独立访客数报表模板.xlsx";

    public static final String EXPORT_USER_ADDRESS_TEMPLATE_PATH = "export/用户地区报表模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_TEMPLATE_PATH = "export/年度计划模版.xlsx";

    public static final String EXPORT_QUARTER_PLAN_TEMPLATE_PATH = "export/季度计划模版.xlsx";

    public static final String EXPORT_MONTH_PLAN_TEMPLATE_PATH = "export/月度计划模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_REVIEW_TEMPLATE_PATH = "export/年度计划总览模版.xlsx";

    public static final String EXPORT_YEAR_PLAN_FAIL_TEMPLATE_PATH = "export/运营计划导出失败模板.xlsx";
}
